@@ -6,106 +6,34 @@
 
 '''A simple Twitter client made with pyqt4'''
 
-USE_PYSIDE = False
-
-if not USE_PYSIDE:
-    import sip
-    sip.setapi('QString', 2)
-    sip.setapi('QVariant', 2)
-
-    from PyQt4.QtGui import *
-    from PyQt4.QtCore import *
-
-    try:
-        from PyQt4.QtMobility.QtLocation import *
-        noQtLocation = False
-    except:
-        noQtLocation = True
-
-    try:   
-        from PyQt4.QtMaemo5 import *
-        isMAEMO = True
-    except:
-        isMAEMO = False
-
-else:
-    from PySide.QtCore import * #PySide
-    from PySide.QtGui import * #PySide
-    pyqtSlot = Slot
-    pyqtSignal = Signal
-    try:
-        from PySide.QtMobility.QtLocation import * #PySide
-        noQtLocation = False
-    except:
-        noQtLocation = True
-
-    try:   
-        from PySide.QtMaemo5 import * #PySide        
-        isMAEMO = True
-    except:
-        isMAEMO = False
-
-
-import twitter
-import sys
-import os.path
-from urllib import urlretrieve
-import datetime
-import time
-try:
-    import dbus
-    import dbus.service
-    from dbus.mainloop.qt import DBusQtMainLoop
-    from dbusobj import KhweeteurDBus
-    noDBUS = False
-except:
-    noDBUS = True
-import pickle
-try:
-    from PIL import Image
-except:
-    import Image
-import re
-import urllib2
-import socket
-import glob
-
-from settings import KhweeteurPref
 from utils import *
 from notifications import KhweeteurNotification
 
-__version__ = '0.0.61'
-
-# ~ class KhweeteurSingleNotify(QObject):
-     # ~ def __init__(self,title,message,iconpath):
-        # ~ QObject.__init__(self)
-
-        # ~ n = pynotify.Notification(title, message, "khweeteur")
-        # ~ n.set_icon_from_pixbuf(icon)
-
+__version__ = '0.1.2'
 
 class KhweeteurActionWorker(QThread):
 
     '''ActionWorker : Post tweet in background'''
 
+    info = pyqtSignal(unicode)
+    warn = pyqtSignal(unicode)
+    tweetSent = pyqtSignal()
+#    finished = pyqtSignal()
+        
     def __init__(
         self,
         parent=None,
         action=None,
-        data=None,
-        data2=None,
-        data3=None,
-        data4=None,
-        data5=None,
+        data=(None,None,None,None,None),
         ):
         QThread.__init__(self, parent)
         self.settings = QSettings()
         self.action = action
-        self.data = data
-        self.tb_text_replyid = data2
-        self.tb_text_replytext = data3
-        self.tb_text_replysource = data4
-        self.geolocation = data5
+        self.data = data[0]
+        self.tb_text_replyid = data[1]
+        self.tb_text_replytext = data[2]
+        self.tb_text_replysource = data[3]
+        self.geolocation = data[4]
 
     def run(self):
         '''Run the background thread'''
@@ -169,8 +97,7 @@ class KhweeteurActionWorker(QThread):
                         api.PostUpdate(status_text,
                                 in_reply_to_status_id=self.tb_text_replyid,
                                 latitude=latitude, longitude=longitude)
-                    self.emit(SIGNAL('info(PyQt_PyObject)'),
-                              'Tweet sent to Twitter')
+                    self.info.emit('Tweet sent to Twitter')
 
             if 'http://identi.ca/api/' == self.tb_text_replysource \
                 or self.tb_text_replyid == 0:
@@ -193,17 +120,15 @@ class KhweeteurActionWorker(QThread):
                         api.PostUpdate(status_text,
                                 in_reply_to_status_id=self.tb_text_replyid,
                                 latitude=latitude, longitude=longitude)
-                    self.emit(SIGNAL('info(PyQt_PyObject)'),
-                              'Tweet sent to Identica')
+                    self.info.emit('Tweet sent to Identica')
 
-            self.emit(SIGNAL('tweetSent()'))
+            self.tweetSent.emit()
         except twitter.TwitterError, e:
 
-            self.emit(SIGNAL('warn(PyQt_PyObject)'), e.message)
+            self.warn.emit(e.message)
             print e.message
         except:
-            self.emit(SIGNAL('warn(PyQt_PyObject)'),
-                      'A network error occur')
+            self.warn.emit('A network error occur')
             print 'A network error occur'
             import traceback
             traceback.print_exc()
@@ -610,6 +535,9 @@ class KhweeteurWorker(QThread):
 
     ''' Thread to Refresh in background '''
 
+    newStatuses = pyqtSignal(list)
+    info = pyqtSignal(unicode)
+    
     def __init__(
         self,
         parent=None,
@@ -660,7 +588,7 @@ class KhweeteurWorker(QThread):
             self.refresh_search_worker1 = KhweeteurSearchWorker(self,
                     api, self.search_keyword, self.geocode)
             self.refresh_search_worker1.errors.connect(self.errors)
-            self.refresh_search_worker1.newStatuses.connect(self.newStatuses)
+            self.refresh_search_worker1.newStatuses.connect(self.transmitNewStatuses)
             self.refresh_search_worker1.start()
 
         if self.settings.value('identica_access_token_key') != None:
@@ -675,7 +603,7 @@ class KhweeteurWorker(QThread):
             self.refresh_search_worker2 = KhweeteurSearchWorker(self,
                     api2, self.search_keyword, self.geocode)
             self.refresh_search_worker2.errors.connect(self.errors)
-            self.refresh_search_worker2.newStatuses.connect(self.newStatuses)
+            self.refresh_search_worker2.newStatuses.connect(self.transmitNewStatuses)
             self.refresh_search_worker2.start()
 
         if self.settings.value('twitter_access_token_key') != None \
@@ -695,51 +623,50 @@ class KhweeteurWorker(QThread):
             if type(self.error) == twitter.TwitterError:
                 print 'Error during twitter refresh : ', \
                     self.error.message
-                self.emit(SIGNAL('info(PyQt_PyObject)'),
-                          self.error.message)  # fix bug#404
+                self.info.emit(self.error.message)  # fix bug#404
             else:
-                self.emit(SIGNAL('info(PyQt_PyObject)'),
-                          self.tr('A network error occur'))
-
+                self.info.emit(self.tr('A network error occur'))
+        
     def errors(self, error):
         self.error = error
         print 'errors : ', error
 
-    def newStatuses(self, list):
-        self.emit(SIGNAL('newStatuses(PyQt_PyObject)'), list)
-
+    def transmitNewStatuses(self, alist):
+#        self.emit(SIGNAL('newStatuses(list)'), list)
+        self.newStatuses.emit(alist)
+        
     def refresh_unified(self, api):
         refresh_timeline_worker = KhweeteurHomeTimelineWorker(self, api)
         refresh_timeline_worker.errors.connect(self.errors)
-        refresh_timeline_worker.newStatuses.connect(self.newStatuses)
+        refresh_timeline_worker.newStatuses.connect(self.transmitNewStatuses)
         refresh_timeline_worker.start()
 
         refresh_retweetsofme_worker = KhweeteurRetweetsOfMeWorker(self,
                 api)
         refresh_retweetsofme_worker.errors.connect(self.errors)
-        refresh_retweetsofme_worker.newStatuses.connect(self.newStatuses)
+        refresh_retweetsofme_worker.newStatuses.connect(self.transmitNewStatuses)
         refresh_retweetsofme_worker.start()
 
         refresh_retweetedbyme_worker = \
             KhweeteurRetweetedByMeWorker(self, api)
         if 'twitter' in api.base_url:
             refresh_retweetedbyme_worker.errors.connect(self.errors)
-            refresh_retweetedbyme_worker.newStatuses.connect(self.newStatuses)
+            refresh_retweetedbyme_worker.newStatuses.connect(self.transmitNewStatuses)
             refresh_retweetedbyme_worker.start()
 
         refresh_replies_worker = KhweeteurRepliesWorker(self, api)
         refresh_replies_worker.errors.connect(self.errors)
-        refresh_replies_worker.newStatuses.connect(self.newStatuses)
+        refresh_replies_worker.newStatuses.connect(self.transmitNewStatuses)
         refresh_replies_worker.start()
 
         refresh_dm_worker = KhweeteurDMWorker(self, api)
         refresh_dm_worker.errors.connect(self.errors)
-        refresh_dm_worker.newStatuses.connect(self.newStatuses)
+        refresh_dm_worker.newStatuses.connect(self.transmitNewStatuses)
         refresh_dm_worker.start()
 
         refresh_mention_worker = KhweeteurMentionWorker(self, api)
         refresh_mention_worker.errors.connect(self.errors)
-        refresh_mention_worker.newStatuses.connect(self.newStatuses)
+        refresh_mention_worker.newStatuses.connect(self.transmitNewStatuses)
         refresh_mention_worker.start()
 
         if 'twitter' in api.base_url:
@@ -757,7 +684,7 @@ class KhweeteurWorker(QThread):
                     refresh_replies_worker, refresh_dm_worker,
                     refresh_mention_worker]
 
-    def refresh(self):
+    def refresh(self):        
         self.error = None
         threads = []
 
@@ -780,10 +707,9 @@ class KhweeteurWorker(QThread):
         except twitter.TwitterError, e:
 
             print 'Error during twitter refresh : ', e.message
-            self.emit(SIGNAL('info(PyQt_PyObject)'), e.message)
+            self.info.emit(e.message)
         except StandardError, e:
-            self.emit(SIGNAL('info(PyQt_PyObject)'),
-                      'A network error occur')
+            self.info.emit('A network error occur')
             print e
 
         try:
@@ -803,10 +729,9 @@ class KhweeteurWorker(QThread):
                 threads.extend(self.refresh_unified(self.identica_api))
         except twitter.TwitterError, e:
             print 'Error during identi.ca refresh: ', e.message
-            self.emit(SIGNAL('info(PyQt_PyObject)'), e.message)
+            self.info.emit(e.message)
         except:
-            self.emit(SIGNAL('info(PyQt_PyObject)'),
-                      'A network error occur')
+            self.info.emit('A network error occur')
 
         while any(thread.isRunning() == True for thread in threads):
             self.sleep(2)
@@ -817,17 +742,17 @@ class KhweeteurWorker(QThread):
             if type(self.error) == twitter.TwitterError:
                 print 'Error during twitter refresh : ', \
                     self.error.message
-                self.emit(SIGNAL('info(PyQt_PyObject)'),
-                          self.error.message)  # fix bug#404
+                self.info.emit(self.error.message)  # fix bug#404
             else:
-                self.emit(SIGNAL('info(PyQt_PyObject)'),
-                          'A network error occur')
+                self.info.emit('A network error occur')
 
 
 class KhweetsModel(QAbstractListModel):
 
     """ListModel : A simple list : Start_At,TweetId, Users Screen_name, Tweet Text, Profile Image"""
 
+    dataChanged = pyqtSignal(QModelIndex,QModelIndex)
+    
     def __init__(self, keyword=None):
         QAbstractListModel.__init__(self)
 
@@ -903,11 +828,13 @@ class KhweetsModel(QAbstractListModel):
             except StandardError, e:
                 print e
 
-        QObject.emit(self,
-                     SIGNAL('dataChanged(const QModelIndex&, const QModelIndex &)'
-                     ), self.createIndex(0, 0), self.createIndex(0,
-                     len(self._uids)))
-
+#        QObject.emit(self,
+#                     SIGNAL('dataChanged(const QModelIndex&, const QModelIndex &)'
+#                     ), self.createIndex(0, 0), self.createIndex(0,
+#                     len(self._uids)))
+        self.dataChanged.emit(self.createIndex(0, 0),
+                              self.createIndex(0,
+                              len(self._items)))
     def addStatuses(self, uids):
         try:
             keys = []
@@ -918,9 +845,10 @@ class KhweetsModel(QAbstractListModel):
                     status = pickle.load(pkl_file)
                     pkl_file.close()
 
-                    self._appendStatusInList(status)
-
-                    keys.append(status.id)
+                    #Test if status already exists
+                    if self._appendStatusInList(status):
+                        keys.append(status.id)
+                        
                 except IOError, e:
                     print e
         except StandardError, e:
@@ -935,20 +863,24 @@ class KhweetsModel(QAbstractListModel):
             self._items = self._items[:self.khweets_limit]
             self._new_counter += len(keys)
 
-            QObject.emit(self,
-                         SIGNAL('dataChanged(const QModelIndex&, const QModelIndex &)'
-                         ), self.createIndex(0, 0), self.createIndex(0,
-                         len(self._items)))
-
+#            QObject.emit(self,
+#                         SIGNAL('dataChanged(const QModelIndex&, const QModelIndex &)'
+#                         ), self.createIndex(0, 0), self.createIndex(0,
+#                         len(self._items)))
+            self.dataChanged.emit(self.createIndex(0, 0),
+                                  self.createIndex(0,
+                                  len(self._items)))
             # self.serialize()
 
     def destroyStatus(self, index):
         self._items.pop(index.row())
-        QObject.emit(self,
-                     SIGNAL('dataChanged(const QModelIndex&, const QModelIndex &)'
-                     ), self.createIndex(0, 0), self.createIndex(0,
-                     len(self._items)))
-
+#        QObject.emit(self,
+#                     SIGNAL('dataChanged(const QModelIndex&, const QModelIndex &)'
+#                     ), self.createIndex(0, 0), self.createIndex(0,
+#                     len(self._items)))
+        self.dataChanged.emit(self.createIndex(0, 0),
+                              self.createIndex(0,
+                              len(self._items)))
     def getNewAndReset(self):
         counter = self._new_counter
         self._new_counter = 0
@@ -967,7 +899,7 @@ class KhweetsModel(QAbstractListModel):
 
     def _appendStatusInList(self, status):
         if status.id in self._uids:
-            return
+            return False
 
         # Created_at, Status.id, ScreenName, Text, Rel_Created_at, Profile Image, Reply_ID, Reply_ScreenName, Reply_Text
 
@@ -1026,6 +958,7 @@ class KhweetsModel(QAbstractListModel):
             ))
 
         self._uids.append(status.id)
+        return True
 
     def _createCacheList(self, cach_path, uids):
         for uid in uids:
@@ -1071,11 +1004,13 @@ class KhweetsModel(QAbstractListModel):
                 self._items.reverse()
         except StandardError, e:
             print 'unSerialize : ', e
-            QObject.emit(self,
-                         SIGNAL('dataChanged(const QModelIndex&, const QModelIndex &)'
-                         ), self.createIndex(0, 0), self.createIndex(0,
-                         len(self._items)))
-
+#            QObject.emit(self,
+#                         SIGNAL('dataChanged(const QModelIndex&, const QModelIndex &)'
+#                         ), self.createIndex(0, 0), self.createIndex(0,
+#                         len(self._items)))
+            self.dataChanged.emit(self.createIndex(0, 0),
+                                  self.createIndex(0,
+                                  len(self._items)))
     def data(self, index, role=Qt.DisplayRole):
 
         # 0 -> Created_at,
@@ -1248,9 +1183,16 @@ class DefaultCustomDelegate(QStyledItemDelegate):
         ):
         '''Paint our tweet'''
 
-        # Ugly hack ?
+        if not USE_PYSIDE:
+            (x1, y1, x2, y2) = option.rect.getCoords()
+        else:
+            #Work arround Pyside bug #544
+            y1 = option.rect.y()
+            y2 = y1 + option.rect.height()
+            x1 = option.rect.x()
+            x2 = x1 + option.rect.width()
 
-        (x1, y1, x2, y2) = option.rect.getCoords()
+        # Ugly hack ?
         if y1 < 0 and y2 < 0:
             return
 
@@ -1447,7 +1389,7 @@ class KhweeteurAbout(QMainWindow):
             aboutScrollArea = QScrollArea(self)
             aboutScrollArea.setWidgetResizable(True)
             awidget = QWidget(aboutScrollArea)
-            awidget.setMinimumSize(480, 1200)
+            awidget.setMinimumSize(480, 1300)
             awidget.setSizePolicy(QSizePolicy.Expanding,
                                   QSizePolicy.Expanding)
             aboutScrollArea.setSizePolicy(QSizePolicy.Expanding,
@@ -1736,7 +1678,8 @@ class KhweeteurWin(QMainWindow):
         self.tb_text_replyid = 0
         self.tb_text_replytext = ''
         self.tb_text_replysource = ''
-        self.tb_text.enabledChange(True)
+        if not USE_PYSIDE:
+            self.tb_text.enabledChange(True)
         self.toolbar.addWidget(self.tb_text)
 
         self.tb_charCounter = QLabel('140')
@@ -1752,7 +1695,7 @@ class KhweeteurWin(QMainWindow):
                 QAction(QIcon(os.path.join(os.path.dirname(os.path.abspath(__file__)),
                         'icons', 'khweeteur.png')), 'Tweet', self)
 
-        self.connect(self.tb_tweet, SIGNAL('triggered()'), self.tweet)
+        self.tb_tweet.triggered.connect(self.tweet)
         self.toolbar.addAction(self.tb_tweet)
 
         if isMAEMO:
@@ -1769,14 +1712,12 @@ class KhweeteurWin(QMainWindow):
 
         self.tb_scrolltop = QAction('Scroll to top', self)
         self.tb_scrolltop.setShortcut(Qt.CTRL + Qt.Key_Up)
-        self.connect(self.tb_scrolltop, SIGNAL('triggered()'),
-                     self.scrolltop)
+        self.tb_scrolltop.triggered.connect(self.scrolltop)
         self.addAction(self.tb_scrolltop)
 
         self.tb_scrollbottom = QAction('Scroll to bottom', self)
         self.tb_scrollbottom.setShortcut(Qt.CTRL + Qt.Key_Down)
-        self.connect(self.tb_scrollbottom, SIGNAL('triggered()'),
-                     self.scrollbottom)
+        self.tb_scrollbottom.triggered.connect(self.scrollbottom)
         self.addAction(self.tb_scrollbottom)
 
         QTimer.singleShot(200, self.timedUnserialize)
@@ -1793,18 +1734,12 @@ class KhweeteurWin(QMainWindow):
             user = self.tweetsModel.data(index, role=SCREENNAMEROLE)
         if user:
             self.tweetActionDialog = KhweetAction(self, user)
-            self.connect(self.tweetActionDialog.reply,
-                         SIGNAL('clicked()'), self.reply)
-            self.connect(self.tweetActionDialog.openurl,
-                         SIGNAL('clicked()'), self.open_url)
-            self.connect(self.tweetActionDialog.retweet,
-                         SIGNAL('clicked()'), self.retweet)
-            self.connect(self.tweetActionDialog.follow,
-                         SIGNAL('clicked()'), self.follow)
-            self.connect(self.tweetActionDialog.unfollow,
-                         SIGNAL('clicked()'), self.unfollow)
-            self.connect(self.tweetActionDialog.destroy_tweet,
-                         SIGNAL('clicked()'), self.destroy_tweet)
+            self.tweetActionDialog.reply.clicked.connect(self.reply)
+            self.tweetActionDialog.openurl.clicked.connect(self.open_url)
+            self.tweetActionDialog.retweet.clicked.connect(self.retweet)
+            self.tweetActionDialog.follow.clicked.connect(self.follow)
+            self.tweetActionDialog.unfollow.clicked.connect(self.unfollow)
+            self.tweetActionDialog.destroy_tweet.clicked.connect(self.destroy_tweet)
             self.tweetActionDialog.exec_()
 
     def countCharsAndResize(self):
@@ -2214,22 +2149,18 @@ class KhweeteurWin(QMainWindow):
             self.tweetAction = KhweeteurActionWorker(
                 self,
                 'tweet',
-                unicode(self.tb_text.toPlainText()).encode('utf-8'),
+                (unicode(self.tb_text.toPlainText()).encode('utf-8'),
                 self.tb_text_replyid,
                 self.tb_text_replytext,
                 self.tb_text_replysource,
-                geoposition,
+                geoposition),
                 )
-            self.connect(self.tweetAction, SIGNAL('tweetSent()'),
-                         self.tweetSent)
-            self.connect(self.tweetAction, SIGNAL('finished()'),
-                         self.tweetSentFinished)
-            self.notifications.connect(self.tweetAction,
-                    SIGNAL('info(PyQt_PyObject)'),
-                    self.notifications.info)
-            self.notifications.connect(self.tweetAction,
-                    SIGNAL('warn(PyQt_PyObject)'),
-                    self.notifications.warn)
+            self.tweetAction.tweetSent.connect(self.tweetSent)
+            self.tweetAction.finished.connect(self.tweetSentFinished)
+            self.tweetAction.info.connect(self.notifications.info)
+            self.tweetAction.warn.connect(self.notifications.warn)
+            self.tweetAction.tweetSent.connect(self.tweetSentFinished)
+            self.tweetAction.finished.connect(self.tweetSent)
             self.tweetAction.start()
 
     def refreshEnded(self):
@@ -2256,14 +2187,13 @@ class KhweeteurWin(QMainWindow):
         if not self.worker:
             self.worker = KhweeteurWorker(self,
                     search_keyword=self.search_keyword, geocode=geocode)
-            self.connect(self.worker,
-                         SIGNAL('newStatuses(PyQt_PyObject)'),
-                         self.tweetsModel.addStatuses)
+#            self.connect(self.worker,
+#                         SIGNAL('newStatuses(tuple)'),
+#                         self.tweetsModel.addStatuses)
+            self.worker.newStatuses.connect(self.tweetsModel.addStatuses)
             self.connect(self.worker, SIGNAL('finished()'),
                          self.refreshEnded)
-            self.notifications.connect(self.worker,
-                    SIGNAL('info(PyQt_PyObject)'),
-                    self.notifications.info)
+            self.worker.info.connect(self.notifications.info)
         else:
             self.worker.geocode = geocode
         self.worker.start()
@@ -2332,6 +2262,9 @@ class KhweeteurWin(QMainWindow):
         fileMenu.addAction(self.tr('&Search'), self.open_search,
                            QKeySequence(self.tr('Ctrl+S', 'Search')))
 
+#        fileMenu.addAction(self.tr('&TwitPic Upload'), self.twitpic_upload,
+#                           QKeySequence(self.tr('Ctrl+T', 'Twitpic Upload')))
+
         if self.search_keyword != None:
             keywords = self.settings.value('savedSearch')
             if keywords != None:
@@ -2347,6 +2280,29 @@ class KhweeteurWin(QMainWindow):
 
         fileMenu.addAction(self.tr('&About'), self.do_about)
 
+    def twitpic_upload(self):
+        message = 'Test'
+        import twitpic2
+        api = \
+            twitter.Api(username=KHWEETEUR_TWITTER_CONSUMER_KEY,
+                password=KHWEETEUR_TWITTER_CONSUMER_SECRET,
+                access_token_key=str(self.settings.value('twitter_access_token_key'
+                )),
+                access_token_secret=str(self.settings.value('twitter_access_token_secret'
+                )))
+        twitpic = twitpic2.TwitPicOAuthClient(
+            consumer_key = KHWEETEUR_TWITTER_CONSUMER_KEY,
+            consumer_secret = KHWEETEUR_TWITTER_CONSUMER_SECRET,
+            access_token = ACCESS_TOKEN, #FIXME
+            service_key = 'f9b7357e0dc5473df5f141145e4dceb0'
+            )
+        # methods - read, create, update, remove
+        params = []
+        params['media'] = 'khweeteur.png'
+        params['message'] = 'Test of python-twitpic module from #Khweeteur'
+        response = twitpic2.create('upload', params)
+        print response
+        
     def del_search(self):
         keywords = self.settings.value('savedSearch')
         if not keywords:
@@ -2401,7 +2357,7 @@ class KhweeteurWin(QMainWindow):
 
     def do_show_pref(self):
         self.pref_win = KhweeteurPref(self)
-        self.connect(self.pref_win, SIGNAL('save()'), self.restartTimer)
+        self.pref_win.save.connect(self.restartTimer)
         self.pref_win.show()
 
     def do_about(self):
